"""
jivas package initialization.

JIVAS is an Agentic Framework for rapidly prototyping and deploying graph-based, AI solutions.
"""

from importlib.metadata import version

__version__ = version("jivas")
